@@ -14,6 +14,8 @@
 #'
 #' @param parallel \code{logical}. if TRUE, the Least Cost Paths will be calculated in parallel. Number of Parallel socket clusters is total number of cores available minus 1. Default is FALSE
 #'
+#' @references Verhagen, P. (2013). On the road to nowhere? Least cost paths, accessibility and the predictive modelling perspective. In Contreras F, Farjas M, Melero FJ (eds). Fusion of cultures. Proceedings of the 38th annual conference on computer applications and quantitative methods in archaeology, Granada, Spain, April 2010. (pp 383-389). Oxford: Archaeopress
+#'
 #' @return \code{SpatialLinesDataFrame} (sp package). The resultant object contains least cost paths (number of LCPs is dependent on radial_points argument) calculated from radial locations to a centre location within a specified distance.
 #'
 #' @author Joseph Lewis
@@ -121,6 +123,8 @@ create_CCP_lcps <- function(cost_surface, location, distance, radial_points, cos
         
         lcp_network$cost <- cost_dist
         
+        lcp_network <- lcp_network[order(lcp_network$cost), ]
+        
     }
     
     return(lcp_network)
